<?php use Lunovus\ExternalStore\Helpers; ?>

<div class="t-container t-px-10 t-flex" style="max-width: 80%">

    <!-- Product categories -->
    <div class="t-w-1/3">
        <a href="/shop" class="t-block t-my-2 
            <?php if ($categorySlug == 'all') echo 't-no-underline t-font-bold' ?>
        ">
            All (<?php echo array_sum(array_column($categories, 'products')) ?>)
        </a>
        <?php foreach ($categories as $category): ?>
            <a href="/shop/<?php echo $category->slug ?>"
                class="t-block t-my-2
                    <?php if ($currentCategory->id == $category->id) echo 't-no-underline t-font-bold' ?>
            ">
                <?php echo $category->title ?> (<?php echo $category->products ?>)
            </a>
        <?php endforeach ?>

        <!-- Sorting options -->
        <div class="t-mt-8 t-flex t-flex-col">
            <label for="lunovus-sort">Sort By</label>
            <a href="<?php echo Helpers::modifyQueryString('order', ['title', 'desc']) ?>">Title desc</a>
            <a href="<?php echo Helpers::modifyQueryString('order', ['title', 'asc']) ?>">Title asc</a>
            <a href="<?php echo Helpers::modifyQueryString('order', ['min_price', 'desc']) ?>">Price desc</a>
            <a href="<?php echo Helpers::modifyQueryString('order', ['min_price', 'asc']) ?>">Price asc</a>
        </div>

        <!-- Limit options -->
        <div class="t-mt-8 t-flex t-flex-col">
            <label for="lunovus-sort">Limit</label>
            <a href="<?php echo Helpers::modifyQueryString('limit', 30) ?>">Limit = 30</a>
            <a href="<?php echo Helpers::modifyQueryString('limit', 10) ?>">Limit = 10</a>
            <a href="<?php echo Helpers::modifyQueryString('limit', 1) ?>">Limit = 1</a>
        </div>

        <!-- Pagination -->
        <div class="t-mt-8 t-flex t-flex-col">
            <label>Pagination</label>
            <p>Total: <?php echo $products->total ?></p>
            <p>Filtered: <?php echo $products->filtered ?></p>

            <?php if ($products->offset > 0): ?>
                <a href="<?php echo Helpers::modifyQueryString('offset', max($products->offset - $products->limit, 0)) ?>">Prev</a>
            <?php endif ?>

            <?php if ($products->hasMore): ?>
                <a href="<?php echo Helpers::modifyQueryString('offset', ($products->offset + $products->limit)) ?>">Next</a>
            <?php endif ?>
        </div>
    </div>

    <!-- Products -->
    <div class="t-w-2/3 t-grid t-grid-cols-3 t-grid-flow-row">
        <?php foreach ($products->data as $product): ?>
            <div class="t-mr-7 t-mb-4 t-pb-9 t-relative">

                <!-- Main image -->
                <div class=" t-p-7 t-bg-slate-100 t-rounded-xl">
                    <img src="<?php echo $product->images[0] ?>" class="t-h-40 t-mx-auto" />
                </div>

                <!-- Title -->
                <a href="/shop/<?php echo $categoriesSlugs[$product->category_id] ?>/<?php echo $product->slug . '-' . $product->commonSku ?>"
                    class="t-font-medium t-leading-loose"
                ><?php echo $product->title ?></a>

                <!-- Description -->
                <p class="t-text-sm t-text-slate-600 t-leading-5 ">
                    <?php echo substr($product->description, 0, strpos($product->description, '.') + 1) ?>
                </p>

                <!-- Price -->
                <b class="t-absolute t-inset-x-0 t-bottom-0 t-text-right t-leading-10 t-border-b t-border-dashed t-border-slate-200">
                    <?php echo Helpers::formatCurrency($product->min_price) ?>
                </b>
            </div>
        <?php endforeach ?>
    </div>
</div>
