<?php namespace Lunovus\ExternalStore;

class API
{
    /**
     * Get categoires
     *
     * @param int $practiceId
     */
    public static function getCategories($practiceId)
    {
        $url = self::buildResourceURL('categories', [
            'practice_id' => $practiceId,
        ]);

        return self::get($url)->data ?: [];
    }

    /**
     * Get products
     *
     * @param int $practiceId
     * @param array $filters
     */
    public static function getProducts($practiceId, $filters = [])
    {
        $filters['practice_id'] = $practiceId;

        $url = self::buildResourceURL('products', $filters);

        return self::get($url) ?: [];
    }

    /**
     * Get one product by SKU
     *
     * @param int $practiceId
     * @param string $sku
     */
    public static function getProduct($practiceId, $sku)
    {
        $url = self::buildResourceURL('products', [
            'practice_id' => $practiceId,
            'sku' => $sku
        ]);

        if (( ! $result = self::get($url))
            || ($result->status != 'success')
        ) {
            return false;
        }

        return current($result->data->data ?? []);
    }

    /**
     * Returns base URL for resource
     *
     * @param string $resource
     * @param array $params
     */
    public static function buildResourceURL($resource, $params = [])
    {
        $url = LUNOVUS_EXTERNAL_STORE__API_URL . $resource . '?';

        return $url . http_build_query($params);
    }

    /**
     * General GET request
     *
     * @param string $url
     * @param array $params
     */
    public static function get($url, $params = [])
    {
        $params = [
            'headers' => [
                'Content-Type' => 'application/json'
            ]
        ];

        try {
            $response = wp_remote_get($url, $params);

            if ( ! is_wp_error($response)
                && (200 === wp_remote_retrieve_response_code($response))
            ) {
                $responseBody = json_decode($response['body']);

                if (json_last_error() === JSON_ERROR_NONE)
                {
                    return $responseBody;
                }
            }
            else
            {
                die(LUNOVUS_EXTERNAL_STORE_NAME . ': ' .  implode(' - ', $response['response']));
            }
        } catch(\Exception $e)
        {
            die(LUNOVUS_EXTERNAL_STORE_NAME . ': ' . $e->getMessage());
        }
    }
}
