<?php namespace Lunovus\ExternalStore;

class AdminSettings
{
    public static $name = 'lunvous_external_store';

    public static function init()
    {
        add_action('admin_init', self::getCallback('registerSettings'));
        add_action('admin_menu', self::getCallback('mainOptionsPage'));
    }

    /**
     * Returns given string prefixed with $name
     *
     * @param string $string
     */
    public static function getName($string = '')
    {
        return self::$name . $string;
    }

    /**
     * Returns callback to own method
     *
     * @param string $methodName
     * @param bool $prefixWithName
     */
    public static function getCallback($methodName, $prefixWithName = false)
    {
        if ($prefixWithName)
        {
            $methodName = self::getName($methodName);
        }

        return ['\Lunovus\ExternalStore\AdminSettings', $methodName];
    }

    public static function mainOptionsPage()
    {
        add_menu_page(
            'Lunovus',
            'Lunovus',
            'manage_options',
            LUNOVUS_EXTERNAL_STORE_NAME,
            self::getCallback('mainMenuHTML'),
            'dashicons-heart',
            78
        );
    }

    public static function mainMenuHTML() 
    {?>
        <div class="wrap">
            <h2><?php echo esc_html(get_admin_page_title()); ?></h2>
            <form action="options.php" method="post">
                <?php
                    settings_errors();
                    settings_fields(self::getName());
                    do_settings_sections(self::getName());
                    submit_button();
                ?>
            </form>
        </div> 
    <?php
    }

    public static function lunvous_external_store_general_cb()
    {
        echo '<p style="display: none">General section description</p>';
    }

    public static function lunvous_external_store_practice_id_callback()
    {
        $name = self::getName('_practice_id');

        $value = get_option($name);

        echo '<input type="text" name="' . $name . '" id="' . $name . '" size="5" value="' . $value . '"> ' . '(Practice ID that owns this store)';
    }

    public static function lunvous_external_store_primary_color_callback()
    {
        $name = self::getName('_primary_color');

        $value = get_option($name, LUNOVUS_EXTERNAL__DEFAULT_PRIMARY_COLOR);

        echo '<input type="color" name="' . $name . '" id="' . $name . '" value="' . $value . '"> ';

        echo '<a href="javascript:void(0)" onClick="
                document.querySelector(\'input[name='.$name.']\').value = \''.LUNOVUS_EXTERNAL__DEFAULT_PRIMARY_COLOR.'\';
            ">Restore Default</a>';
    }
    
    public static function lunvous_external_store_bool_cb()
    {
        $name = self::getName('_bool');

        $value = get_option($name);
?>
            <fieldset>
                <label>
                    <input type="radio" name="<?php echo $name ?>" id="<?php echo $name ?>" value="true" <?php checked( $value, 'true' ); ?>>
                    True
                </label>
                <br>
                <label>
                    <input type="radio" name="<?php echo $name ?>" value="false" <?php checked( $value, 'false' ); ?>>
                    False
                </label>
            </fieldset>
<?php
    }

    public static function registerSettings()
    {
        add_settings_section(
            self::getName('_general'),
            'Configure Lunovus external store',
            self::getCallback('_general_cb', true),
            self::getName()
        );

        // A a boolean field
        /*
        add_settings_field(
            self::getName('_bool'),
            'Boolean setting',
            self::getCallback('_bool_cb', true),
            self::getName(),
            self::getName('_general'),
            ['label_for' => self::getName('_bool')]
        );
        */

        // Add a numeric field
        add_settings_field(
            self::getName('_practice_id'),
            'Practice ID',
            self::getCallback('_practice_id_callback', true),
            self::getName(),
            self::getName('_general'),
            ['label_for' => self::getName('_practice_id')]
        );

        // Primary color
        add_settings_field(
            self::getName('_primary_color'),
            'Primary Color',
            self::getCallback('_primary_color_callback', true),
            self::getName(),
            self::getName('_general'),
            ['label_for' => self::getName('_primary_color')]
        );

        // Register the boolean field
        /*
        register_setting(
            self::getName(),
            self::getName('_bool'),
            self::getCallback('_sanitize_bool', true)
        );
        */

        // Register the numeric field
        register_setting(
            self::getName(),
            self::getName('_practice_id'),
            'integer'
        );

        // Register primary color input
        register_setting(
            self::getName(),
            self::getName('_primary_color'),
            'string'
        );
    }
}

