<?php namespace Lunovus\ExternalStore;

class Helpers
{
    /**
     * Add meta tag to page header
     *
     * @param string $name
     * @param string $content
     */
    public static function addMetaTag($name, $content)
    {
        add_action('wp_head', function() use ($name, $content) {
            echo '<meta name="' . $name . '" content="' . $content . '">';
        });
    }

    /**
     * Set page title
     *
     * @param string $title
     */
    public static function setPageTitle($title)
    {
        add_filter('document_title_parts', function() use ($title) {
            return $title;
        });
    }

    /**
     * Enqueue React script
     *
     * @param string $name
     * @param string $version
     * @param bool $inFooter
     */
    public static function enqueueReactScript($name, $version = false, $inFooter = true)
    {
        $version = $version
            ?? (LUNOVUS_EXTERNAL_STORE__ENVIRONMENT == 'production')
                ? null : time();

        wp_enqueue_script(
            LUNOVUS_EXTERNAL_STORE_NAME . '-' . $name . '-js',
            LUNOVUS_EXTERNAL_STORE__PLUGIN_BUILD_URL . 'js/' . $name . '.js',
            ['wp-element'],
            $version,
            true
        );
    }

    /**
     * Returns layout HTML
     *
     * @param string $layout
     * @param array $params
     */
    public static function getLayoutHTML($layout, $params = [])
    {
        $fileName = $layout . '.php';

        $filePath = LUNOVUS_EXTERNAL_STORE__LAYOUTS_DIR . $fileName;

        if ( ! file_exists($filePath))
        {
            die(LUNOVUS_EXTERNAL_STORE_NAME . ': template file "' . $fileName . '" is missing');
        }

        ob_start();
        extract($params);
        require_once $filePath;

        return ob_get_clean();
    }

    /**
     * Format price
     *
     * @param mix $value
     */
    public static function formatCurrency($value)
    {
        $value = str_replace('$', '', $value);
        $value = str_replace(',', '', $value);
        $value = (float) $value;

        $value = str_replace(',', '', $value);

        if ($value < 0) {
            return '- $' . number_format(abs($value), 2);
        }

        return '$' . number_format($value, 2);
    }

    /**
     * Search array of objects by fiven key and value
     *
     * @param array $array
     * @param string $key
     * @param mixed $value
     */
    public static function arraySearch($array, $key, $value)
    {
        return array_column($array, null, $key)[$value] ?? null;
    }

    /**
     * Modifies and returns current URL query string
     *
     * @param string $key
     * @param mixed $value
     */
    public static function modifyQueryString($key, $value)
    {
        $uri = site_url($_SERVER['PHP_SELF']);
        $queryString = $_SERVER['QUERY_STRING'];

        parse_str($queryString, $parsedQueryString);

        $parsedQueryString[$key] = $value;

        return $uri . '?' . http_build_query($parsedQueryString);
    }

    /**
     * Returns <style> tag with styles that related with plugin setting page.
     * For example - primary color
     */
    public static function pluginSettingsStyles()
    {
        if (LUNOVUS_EXTERNAL__PRIMARY_COLOR != LUNOVUS_EXTERNAL__DEFAULT_PRIMARY_COLOR)
        {
            return "<style>
                .t-border-sky-400 {
                    border-color: " . LUNOVUS_EXTERNAL__PRIMARY_COLOR . "!important;
                }
                .t-bg-sky-400 {
                    background-color: " . LUNOVUS_EXTERNAL__PRIMARY_COLOR . "!important;
                }
                button.hover\:t-bg-sky-300:hover {
                    background-color: " . LUNOVUS_EXTERNAL__PRIMARY_COLOR . "!important;
                    filter: brightness(1.25);
                }
            </style>";
        }
    }
}
